<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}
/**
 * Iconic_WSB_Settings.
 *
 * Any methods related to the plugin settings.
 *
 * @class    Iconic_WSB_Settings
 * @version  1.0.0
 */
class Iconic_WSB_Settings {
	/**
	 * Run.
	 */
	public static function run() {
		add_action( 'init', array( __CLASS__, 'init' ) );
		add_filter( 'woocommerce_json_search_found_products', array( __CLASS__, 'format_ajax_search_results' ) );
	}

	/**
	 * Init.
	 */
	public static function init() {
		global $iconic_wsb_class;

		if ( ! $iconic_wsb_class ) {
			return;
		}

		$iconic_wsb_class->set_settings();
	}

	/**
	 * Add all plugin settings tab
	 *
	 * @param array $settings
	 *
	 * @return array
	 */
	public static function init_tabs( $settings ) {
		$settings['tabs']['order-bump'] = array(
			'id'    => 'order_bump',
			'title' => __( 'Design', 'iconic-wsb' ),
		);

		return $settings;
	}

	/**
	 * Format AJAX Search Results.
	 *
	 * @param array $products Products.
	 * @return array
	 */
	public static function format_ajax_search_results( $products ) {
		$should_display_stock = ! empty( $_GET['display_stock'] ); // phpcs:ignore WordPress.Security.NonceVerification

		foreach ( $products as $product_id => &$product ) {
			$product_object = wc_get_product( $product_id );

			if ( empty( $product_object ) ) {
				continue;
			}

			$product = esc_html( Iconic_WSB_Helpers::get_formatted_name( $product_object ) );

			if ( ! $should_display_stock ) {
				continue;
			}

			if ( ! $product_object->managing_stock() ) {
				continue;
			}

			$stock_amount = $product_object->get_stock_quantity();
			/* Translators: %d stock amount */
			$product .= ' &ndash; ' . sprintf( __( 'Stock: %d', 'woocommerce' ), wc_format_stock_quantity_for_display( $stock_amount, $product_object ) );
		}

		return $products;
	}
}
